/* this is a stater template you can delete and create your own template */
import path from "node:path";
import { fileURLToPath } from "node:url";
import express, { type Request, type Response } from "express";
import process from "node:process";
import dotenv from "dotenv";
import cors from "cors";

// initialize dotenv
dotenv.config();

// setup file paths
const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);
const staticFiles = path.join(__dirname, "public", "index.html");
// setup server port
const port = process.env.PORT || 3000;

// create express app instance  and configure middleware and routes
const app = express();
// parse incoming JSON requests  to req.body  for middleware like body-parser
app.use(express.json());

// configure cors
app.use(
  cors({
    origin: ["http://localhost:3000"],
    credentials: true,
    methods: ["GET", "POST", "PUT", "DELETE", "PATCH"],
    allowedHeaders: ["Content-Type", "Authorization"],
  })
);

//serving static files from public
app.use(express.static(staticFiles));

// simple route example  /api/hello
app.get("/api/hello", (req: Request, res: Response) => {
  res.send("Hello, Buildmatrix!");
});

// start server  and listen on port 3000 or process.env.PORT
app.listen(port, () => {
  console.log(`Server running on port ${port}`);
});
